GaitTypeEnum

Enum GaitTypeEnum 

pub enum GaitTypeEnum {
    Walk,
    Crawl,
    Swim,
    Fly,
    Climb,
}

Variants



Walk

Used for moving normally over flat ground tiles, and up and down ramps and stairs.

Walking gaits are land-based gaits which require the creature to be standing up, and have more than half of their [STANCE] body parts, e.g. legs, intact and working.



Crawl

Used for moving over ground tiles whilst prone.

Unlike walking gaits, crawling gaits do not require either standing up, or [STANCE] body parts. They are much slower than walking gaits in general.

Please note that an uninjured, slithering snake is considered to be using a walking gait, not a crawling gait: its body is its [STANCE] body part. If a snake is injured in the body, it will revert to a crawling gait.



Swim

Used for moving through tiles containing water or magma at a depth of at least 4/7.

In order to swim, a creature needs either the [SWIMS_INNATE] tag, or [SWIMS_LEARNED] along with [CAN_LEARN] and skill in swimming.



Fly

Used for moving through open space. An “Open space” is a map tile state that indicates there is nothing there. No floor, no walls, no creatures, absolutely nothing.

In both Dwarf mode and Adventure mode, you can look at the world around you. A description of the tile being examined will be displayed on the right hand side of the screen.

In order to fly, a creature needs the [FLIER] tag, and for enough of its body parts tagged [FLIER] (e.g. wings) to be intact, if applicable. Flying does not require a minimum speed to stay airborne, and turning while flying is no more difficult than turning while walking.



Climb

Used for moving whilst climbing.

Climbing gaits are used for moving up and down vertical surfaces, such as trees or walls, as well as for moving horizontally while supporting oneself against a vertical surface. In order to climb, a creature needs intact body parts to climb with: [GRASP] body parts by default, or [STANCE] body parts if the creature has the [STANCE_CLIMBER] token. Stance climbers include cats and giant cave spiders.